@@ -1,4 +1,4 @@
-from rest_framework.fields import IntegerField, CharField
+from rest_framework.fields import CharField, IntegerField
 from rest_framework.serializers import Serializer
 
 from bitsoframework.middleware import get_user
