@@ -16,7 +16,7 @@ class MetadataModelService(object):
         return self.models.get(name)
 
     def build_model(self, app_label, model_name):
-        django_model = apps.get_model(app_label, model_name)
+        apps.get_model(app_label, model_name)
         model = MetadataModel(name=model_name)
 
         return model
