@@ -57,7 +57,7 @@ def tokenize_by_camel_case(string, token):
 
         if character != " " and character == string[index]:
 
-            result.append(token);
+            result.append(token)
             result.append(string[index].lower())
 
         else:
@@ -127,7 +127,7 @@ def substring_between(string, before, after):
     if (string is None) or (before is None) or (after is None):
         return None
 
-    start = string.find(before);
+    start = string.find(before)
 
     if start != INDEX_NOT_FOUND:
 
